# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableJoinInput(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_ids_to_include': 'list[str]',
        'column_to_join': 'str',
        'table_definition_id': 'str'
    }

    attribute_map = {
        'column_ids_to_include': 'columnIdsToInclude',
        'column_to_join': 'columnToJoin',
        'table_definition_id': 'tableDefinitionId'
    }

    def __init__(self, column_ids_to_include=None, column_to_join=None, table_definition_id=None):
        """
        TableJoinInput - a model defined in Swagger
        """

        self._column_ids_to_include = None
        self._column_to_join = None
        self._table_definition_id = None

        if column_ids_to_include is not None:
          self.column_ids_to_include = column_ids_to_include
        if column_to_join is not None:
          self.column_to_join = column_to_join
        if table_definition_id is not None:
          self.table_definition_id = table_definition_id

    @property
    def column_ids_to_include(self):
        """
        Gets the column_ids_to_include of this TableJoinInput.
        Column IDs to include from the joined table. Leave empty to include all columns from the join table.

        :return: The column_ids_to_include of this TableJoinInput.
        :rtype: list[str]
        """
        return self._column_ids_to_include

    @column_ids_to_include.setter
    def column_ids_to_include(self, column_ids_to_include):
        """
        Sets the column_ids_to_include of this TableJoinInput.
        Column IDs to include from the joined table. Leave empty to include all columns from the join table.

        :param column_ids_to_include: The column_ids_to_include of this TableJoinInput.
        :type: list[str]
        """

        self._column_ids_to_include = column_ids_to_include

    @property
    def column_to_join(self):
        """
        Gets the column_to_join of this TableJoinInput.
        Optional UUID column ID within the joined table to use as the join key. Must be indexed

        :return: The column_to_join of this TableJoinInput.
        :rtype: str
        """
        return self._column_to_join

    @column_to_join.setter
    def column_to_join(self, column_to_join):
        """
        Sets the column_to_join of this TableJoinInput.
        Optional UUID column ID within the joined table to use as the join key. Must be indexed

        :param column_to_join: The column_to_join of this TableJoinInput.
        :type: str
        """

        self._column_to_join = column_to_join

    @property
    def table_definition_id(self):
        """
        Gets the table_definition_id of this TableJoinInput.
        ID of the table definition to join against

        :return: The table_definition_id of this TableJoinInput.
        :rtype: str
        """
        return self._table_definition_id

    @table_definition_id.setter
    def table_definition_id(self, table_definition_id):
        """
        Sets the table_definition_id of this TableJoinInput.
        ID of the table definition to join against

        :param table_definition_id: The table_definition_id of this TableJoinInput.
        :type: str
        """

        self._table_definition_id = table_definition_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableJoinInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CapsulesOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _capsules: List[CapsuleV1]
    _continuation_token: Optional[str]
    _key_unit_of_measure: Optional[str]
    _limit: Optional[int]
    _next: Optional[str]
    _status_message: Optional[str]
    _warning_count: Optional[int]
    _warning_logs: Optional[List[FormulaLogV1]]


    def __init__(
        self,
        capsules: Optional[List[CapsuleV1]] = None,
        continuation_token: Optional[str] = None,
        key_unit_of_measure: Optional[str] = None,
        limit: Optional[int] = None,
        next: Optional[str] = None,
        status_message: Optional[str] = None,
        warning_count: Optional[int] = None,
        warning_logs: Optional[List[FormulaLogV1]] = None,
    ) -> None: ...

    @property
    def capsules(self) -> List[CapsuleV1]: ...

    @capsules.setter
    def capsules(self, capsules: List[CapsuleV1]) -> None: ...

    @property
    def continuation_token(self) -> Optional[str]: ...

    @continuation_token.setter
    def continuation_token(self, continuation_token: Optional[str]) -> None: ...

    @property
    def key_unit_of_measure(self) -> Optional[str]: ...

    @key_unit_of_measure.setter
    def key_unit_of_measure(self, key_unit_of_measure: Optional[str]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def next(self) -> Optional[str]: ...

    @next.setter
    def next(self, next: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def warning_count(self) -> Optional[int]: ...

    @warning_count.setter
    def warning_count(self, warning_count: Optional[int]) -> None: ...

    @property
    def warning_logs(self) -> Optional[List[FormulaLogV1]]: ...

    @warning_logs.setter
    def warning_logs(self, warning_logs: Optional[List[FormulaLogV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConditionMonitorNotificationConfigurationInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bcc_email_recipients: Optional[List[str]]
    _capsule_grouping: Optional[str]
    _capsule_properties: Optional[List[str]]
    _cc_email_recipients: Optional[List[str]]
    _contextual_text: Optional[str]
    _reply_to_email_recipients: Optional[List[str]]
    _timezone: Optional[str]
    _to_email_recipients: Optional[List[str]]


    def __init__(
        self,
        bcc_email_recipients: Optional[List[str]] = None,
        capsule_grouping: Optional[str] = None,
        capsule_properties: Optional[List[str]] = None,
        cc_email_recipients: Optional[List[str]] = None,
        contextual_text: Optional[str] = None,
        reply_to_email_recipients: Optional[List[str]] = None,
        timezone: Optional[str] = None,
        to_email_recipients: Optional[List[str]] = None,
    ) -> None: ...

    @property
    def bcc_email_recipients(self) -> Optional[List[str]]: ...

    @bcc_email_recipients.setter
    def bcc_email_recipients(self, bcc_email_recipients: Optional[List[str]]) -> None: ...

    @property
    def capsule_grouping(self) -> Optional[str]: ...

    @capsule_grouping.setter
    def capsule_grouping(self, capsule_grouping: Optional[str]) -> None: ...

    @property
    def capsule_properties(self) -> Optional[List[str]]: ...

    @capsule_properties.setter
    def capsule_properties(self, capsule_properties: Optional[List[str]]) -> None: ...

    @property
    def cc_email_recipients(self) -> Optional[List[str]]: ...

    @cc_email_recipients.setter
    def cc_email_recipients(self, cc_email_recipients: Optional[List[str]]) -> None: ...

    @property
    def contextual_text(self) -> Optional[str]: ...

    @contextual_text.setter
    def contextual_text(self, contextual_text: Optional[str]) -> None: ...

    @property
    def reply_to_email_recipients(self) -> Optional[List[str]]: ...

    @reply_to_email_recipients.setter
    def reply_to_email_recipients(self, reply_to_email_recipients: Optional[List[str]]) -> None: ...

    @property
    def timezone(self) -> Optional[str]: ...

    @timezone.setter
    def timezone(self, timezone: Optional[str]) -> None: ...

    @property
    def to_email_recipients(self) -> Optional[List[str]]: ...

    @to_email_recipients.setter
    def to_email_recipients(self, to_email_recipients: Optional[List[str]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ChannelOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: Optional[str]
    _id: Optional[str]
    _last_published_at: Optional[str]
    _published_count: Optional[int]
    _subscriptions: Optional[List[SubscriptionOutputV1]]
    _type: Optional[str]


    def __init__(
        self,
        created_at: Optional[str] = None,
        id: Optional[str] = None,
        last_published_at: Optional[str] = None,
        published_count: Optional[int] = None,
        subscriptions: Optional[List[SubscriptionOutputV1]] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def last_published_at(self) -> Optional[str]: ...

    @last_published_at.setter
    def last_published_at(self, last_published_at: Optional[str]) -> None: ...

    @property
    def published_count(self) -> Optional[int]: ...

    @published_count.setter
    def published_count(self, published_count: Optional[int]) -> None: ...

    @property
    def subscriptions(self) -> Optional[List[SubscriptionOutputV1]]: ...

    @subscriptions.setter
    def subscriptions(self, subscriptions: Optional[List[SubscriptionOutputV1]]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class JiraAttachment(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _content: Optional[Any]
    _filename: Optional[str]
    _media_type: Optional[MediaType]


    def __init__(
        self,
        content: Optional[Any] = None,
        filename: Optional[str] = None,
        media_type: Optional[MediaType] = None,
    ) -> None: ...

    @property
    def content(self) -> Optional[Any]: ...

    @content.setter
    def content(self, content: Optional[Any]) -> None: ...

    @property
    def filename(self) -> Optional[str]: ...

    @filename.setter
    def filename(self, filename: Optional[str]) -> None: ...

    @property
    def media_type(self) -> Optional[MediaType]: ...

    @media_type.setter
    def media_type(self, media_type: Optional[MediaType]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemFinderSearchesOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'has_more': 'bool',
        'items': 'list[ItemPreviewV1]',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'has_more': 'hasMore',
        'items': 'items',
        'warnings': 'warnings'
    }

    def __init__(self, has_more=None, items=None, warnings=None):
        """
        ItemFinderSearchesOutputV1 - a model defined in Swagger
        """

        self._has_more = None
        self._items = None
        self._warnings = None

        if has_more is not None:
          self.has_more = has_more
        if items is not None:
          self.items = items
        if warnings is not None:
          self.warnings = warnings

    @property
    def has_more(self):
        """
        Gets the has_more of this ItemFinderSearchesOutputV1.
        True if there are more items found by the match that were not returned

        :return: The has_more of this ItemFinderSearchesOutputV1.
        :rtype: bool
        """
        return self._has_more

    @has_more.setter
    def has_more(self, has_more):
        """
        Sets the has_more of this ItemFinderSearchesOutputV1.
        True if there are more items found by the match that were not returned

        :param has_more: The has_more of this ItemFinderSearchesOutputV1.
        :type: bool
        """
        if has_more is None:
            raise ValueError("Invalid value for `has_more`, must not be `None`")

        self._has_more = has_more

    @property
    def items(self):
        """
        Gets the items of this ItemFinderSearchesOutputV1.
        The items found

        :return: The items of this ItemFinderSearchesOutputV1.
        :rtype: list[ItemPreviewV1]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this ItemFinderSearchesOutputV1.
        The items found

        :param items: The items of this ItemFinderSearchesOutputV1.
        :type: list[ItemPreviewV1]
        """
        if items is None:
            raise ValueError("Invalid value for `items`, must not be `None`")

        self._items = items

    @property
    def warnings(self):
        """
        Gets the warnings of this ItemFinderSearchesOutputV1.
        Warnings from search execution

        :return: The warnings of this ItemFinderSearchesOutputV1.
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """
        Sets the warnings of this ItemFinderSearchesOutputV1.
        Warnings from search execution

        :param warnings: The warnings of this ItemFinderSearchesOutputV1.
        :type: list[str]
        """
        if warnings is None:
            raise ValueError("Invalid value for `warnings`, must not be `None`")

        self._warnings = warnings

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemFinderSearchesOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConditionMonitorOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'capsule_event_types': 'list[str]',
        'condition_ids': 'list[str]',
        'created_at': 'str',
        'creator': 'IdentityPreviewV1',
        'cron_schedule': 'list[str]',
        'cron_schedule_description': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'enabled': 'bool',
        'executor_id': 'str',
        'first_run_look_back': 'int',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'item_finder_id': 'str',
        'last_run_at': 'str',
        'name': 'str',
        'query_range_look_ahead': 'int',
        'scoped_to': 'str',
        'status_message': 'str',
        'subscriptions': 'list[ItemPreviewV1]',
        'suppressed_conditions': 'list[SuppressedConditionOutputV1]',
        'timezone': 'str',
        'translation_key': 'str',
        'type': 'str',
        'updated_at': 'str',
        'vantages': 'list[ItemPreviewV1]',
        'webhook_url': 'str'
    }

    attribute_map = {
        'capsule_event_types': 'capsuleEventTypes',
        'condition_ids': 'conditionIds',
        'created_at': 'createdAt',
        'creator': 'creator',
        'cron_schedule': 'cronSchedule',
        'cron_schedule_description': 'cronScheduleDescription',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'enabled': 'enabled',
        'executor_id': 'executorId',
        'first_run_look_back': 'firstRunLookBack',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'item_finder_id': 'itemFinderId',
        'last_run_at': 'lastRunAt',
        'name': 'name',
        'query_range_look_ahead': 'queryRangeLookAhead',
        'scoped_to': 'scopedTo',
        'status_message': 'statusMessage',
        'subscriptions': 'subscriptions',
        'suppressed_conditions': 'suppressedConditions',
        'timezone': 'timezone',
        'translation_key': 'translationKey',
        'type': 'type',
        'updated_at': 'updatedAt',
        'vantages': 'vantages',
        'webhook_url': 'webhookUrl'
    }

    def __init__(self, capsule_event_types=None, condition_ids=None, created_at=None, creator=None, cron_schedule=None, cron_schedule_description=None, description=None, effective_permissions=None, enabled=None, executor_id=None, first_run_look_back=None, id=None, is_archived=False, is_redacted=False, item_finder_id=None, last_run_at=None, name=None, query_range_look_ahead=None, scoped_to=None, status_message=None, subscriptions=None, suppressed_conditions=None, timezone=None, translation_key=None, type=None, updated_at=None, vantages=None, webhook_url=None):
        """
        ConditionMonitorOutputV1 - a model defined in Swagger
        """

        self._capsule_event_types = None
        self._condition_ids = None
        self._created_at = None
        self._creator = None
        self._cron_schedule = None
        self._cron_schedule_description = None
        self._description = None
        self._effective_permissions = None
        self._enabled = None
        self._executor_id = None
        self._first_run_look_back = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._item_finder_id = None
        self._last_run_at = None
        self._name = None
        self._query_range_look_ahead = None
        self._scoped_to = None
        self._status_message = None
        self._subscriptions = None
        self._suppressed_conditions = None
        self._timezone = None
        self._translation_key = None
        self._type = None
        self._updated_at = None
        self._vantages = None
        self._webhook_url = None

        if capsule_event_types is not None:
          self.capsule_event_types = capsule_event_types
        if condition_ids is not None:
          self.condition_ids = condition_ids
        if created_at is not None:
          self.created_at = created_at
        if creator is not None:
          self.creator = creator
        if cron_schedule is not None:
          self.cron_schedule = cron_schedule
        if cron_schedule_description is not None:
          self.cron_schedule_description = cron_schedule_description
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if enabled is not None:
          self.enabled = enabled
        if executor_id is not None:
          self.executor_id = executor_id
        if first_run_look_back is not None:
          self.first_run_look_back = first_run_look_back
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if item_finder_id is not None:
          self.item_finder_id = item_finder_id
        if last_run_at is not None:
          self.last_run_at = last_run_at
        if name is not None:
          self.name = name
        if query_range_look_ahead is not None:
          self.query_range_look_ahead = query_range_look_ahead
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if status_message is not None:
          self.status_message = status_message
        if subscriptions is not None:
          self.subscriptions = subscriptions
        if suppressed_conditions is not None:
          self.suppressed_conditions = suppressed_conditions
        if timezone is not None:
          self.timezone = timezone
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if updated_at is not None:
          self.updated_at = updated_at
        if vantages is not None:
          self.vantages = vantages
        if webhook_url is not None:
          self.webhook_url = webhook_url

    @property
    def capsule_event_types(self):
        """
        Gets the capsule_event_types of this ConditionMonitorOutputV1.
        The list of capsule event types to detect. The list can contain one or more of the following values: NEW, BECAME_CERTAIN, STILL_UNCERTAIN, EXTINCT

        :return: The capsule_event_types of this ConditionMonitorOutputV1.
        :rtype: list[str]
        """
        return self._capsule_event_types

    @capsule_event_types.setter
    def capsule_event_types(self, capsule_event_types):
        """
        Sets the capsule_event_types of this ConditionMonitorOutputV1.
        The list of capsule event types to detect. The list can contain one or more of the following values: NEW, BECAME_CERTAIN, STILL_UNCERTAIN, EXTINCT

        :param capsule_event_types: The capsule_event_types of this ConditionMonitorOutputV1.
        :type: list[str]
        """
        if capsule_event_types is None:
            raise ValueError("Invalid value for `capsule_event_types`, must not be `None`")

        self._capsule_event_types = capsule_event_types

    @property
    def condition_ids(self):
        """
        Gets the condition_ids of this ConditionMonitorOutputV1.
        The IDs of the monitored conditions

        :return: The condition_ids of this ConditionMonitorOutputV1.
        :rtype: list[str]
        """
        return self._condition_ids

    @condition_ids.setter
    def condition_ids(self, condition_ids):
        """
        Sets the condition_ids of this ConditionMonitorOutputV1.
        The IDs of the monitored conditions

        :param condition_ids: The condition_ids of this ConditionMonitorOutputV1.
        :type: list[str]
        """
        if condition_ids is None:
            raise ValueError("Invalid value for `condition_ids`, must not be `None`")

        self._condition_ids = condition_ids

    @property
    def created_at(self):
        """
        Gets the created_at of this ConditionMonitorOutputV1.
        The time the condition monitor was created

        :return: The created_at of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ConditionMonitorOutputV1.
        The time the condition monitor was created

        :param created_at: The created_at of this ConditionMonitorOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def creator(self):
        """
        Gets the creator of this ConditionMonitorOutputV1.

        :return: The creator of this ConditionMonitorOutputV1.
        :rtype: IdentityPreviewV1
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """
        Sets the creator of this ConditionMonitorOutputV1.

        :param creator: The creator of this ConditionMonitorOutputV1.
        :type: IdentityPreviewV1
        """

        self._creator = creator

    @property
    def cron_schedule(self):
        """
        Gets the cron_schedule of this ConditionMonitorOutputV1.
        The condition monitor's check interval(s) as a list of cron expressions (see https://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :return: The cron_schedule of this ConditionMonitorOutputV1.
        :rtype: list[str]
        """
        return self._cron_schedule

    @cron_schedule.setter
    def cron_schedule(self, cron_schedule):
        """
        Sets the cron_schedule of this ConditionMonitorOutputV1.
        The condition monitor's check interval(s) as a list of cron expressions (see https://www.quartz-scheduler.org/documentation/quartz-2.3.0/tutorials/crontrigger.html)

        :param cron_schedule: The cron_schedule of this ConditionMonitorOutputV1.
        :type: list[str]
        """

        self._cron_schedule = cron_schedule

    @property
    def cron_schedule_description(self):
        """
        Gets the cron_schedule_description of this ConditionMonitorOutputV1.
        A human readable description of the cron schedule

        :return: The cron_schedule_description of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._cron_schedule_description

    @cron_schedule_description.setter
    def cron_schedule_description(self, cron_schedule_description):
        """
        Sets the cron_schedule_description of this ConditionMonitorOutputV1.
        A human readable description of the cron schedule

        :param cron_schedule_description: The cron_schedule_description of this ConditionMonitorOutputV1.
        :type: str
        """

        self._cron_schedule_description = cron_schedule_description

    @property
    def description(self):
        """
        Gets the description of this ConditionMonitorOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ConditionMonitorOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this ConditionMonitorOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this ConditionMonitorOutputV1.

        :return: The effective_permissions of this ConditionMonitorOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this ConditionMonitorOutputV1.

        :param effective_permissions: The effective_permissions of this ConditionMonitorOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def enabled(self):
        """
        Gets the enabled of this ConditionMonitorOutputV1.
        Whether this condition monitor is enabled or not

        :return: The enabled of this ConditionMonitorOutputV1.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this ConditionMonitorOutputV1.
        Whether this condition monitor is enabled or not

        :param enabled: The enabled of this ConditionMonitorOutputV1.
        :type: bool
        """
        if enabled is None:
            raise ValueError("Invalid value for `enabled`, must not be `None`")

        self._enabled = enabled

    @property
    def executor_id(self):
        """
        Gets the executor_id of this ConditionMonitorOutputV1.
        ID of the monitor's creator

        :return: The executor_id of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._executor_id

    @executor_id.setter
    def executor_id(self, executor_id):
        """
        Sets the executor_id of this ConditionMonitorOutputV1.
        ID of the monitor's creator

        :param executor_id: The executor_id of this ConditionMonitorOutputV1.
        :type: str
        """
        if executor_id is None:
            raise ValueError("Invalid value for `executor_id`, must not be `None`")

        self._executor_id = executor_id

    @property
    def first_run_look_back(self):
        """
        Gets the first_run_look_back of this ConditionMonitorOutputV1.
        On first run, how far to look back for capsules, in seconds

        :return: The first_run_look_back of this ConditionMonitorOutputV1.
        :rtype: int
        """
        return self._first_run_look_back

    @first_run_look_back.setter
    def first_run_look_back(self, first_run_look_back):
        """
        Sets the first_run_look_back of this ConditionMonitorOutputV1.
        On first run, how far to look back for capsules, in seconds

        :param first_run_look_back: The first_run_look_back of this ConditionMonitorOutputV1.
        :type: int
        """

        self._first_run_look_back = first_run_look_back

    @property
    def id(self):
        """
        Gets the id of this ConditionMonitorOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ConditionMonitorOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this ConditionMonitorOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this ConditionMonitorOutputV1.
        Whether item is archived

        :return: The is_archived of this ConditionMonitorOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this ConditionMonitorOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this ConditionMonitorOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this ConditionMonitorOutputV1.
        Whether item is redacted

        :return: The is_redacted of this ConditionMonitorOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this ConditionMonitorOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this ConditionMonitorOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def item_finder_id(self):
        """
        Gets the item_finder_id of this ConditionMonitorOutputV1.
        The ID, if present, of the Item Finder that populates the list of condition IDs

        :return: The item_finder_id of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._item_finder_id

    @item_finder_id.setter
    def item_finder_id(self, item_finder_id):
        """
        Sets the item_finder_id of this ConditionMonitorOutputV1.
        The ID, if present, of the Item Finder that populates the list of condition IDs

        :param item_finder_id: The item_finder_id of this ConditionMonitorOutputV1.
        :type: str
        """

        self._item_finder_id = item_finder_id

    @property
    def last_run_at(self):
        """
        Gets the last_run_at of this ConditionMonitorOutputV1.
        The last time the condition monitor job was run

        :return: The last_run_at of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._last_run_at

    @last_run_at.setter
    def last_run_at(self, last_run_at):
        """
        Sets the last_run_at of this ConditionMonitorOutputV1.
        The last time the condition monitor job was run

        :param last_run_at: The last_run_at of this ConditionMonitorOutputV1.
        :type: str
        """

        self._last_run_at = last_run_at

    @property
    def name(self):
        """
        Gets the name of this ConditionMonitorOutputV1.
        The human readable name

        :return: The name of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ConditionMonitorOutputV1.
        The human readable name

        :param name: The name of this ConditionMonitorOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def query_range_look_ahead(self):
        """
        Gets the query_range_look_ahead of this ConditionMonitorOutputV1.
        Query range look ahead in seconds

        :return: The query_range_look_ahead of this ConditionMonitorOutputV1.
        :rtype: int
        """
        return self._query_range_look_ahead

    @query_range_look_ahead.setter
    def query_range_look_ahead(self, query_range_look_ahead):
        """
        Sets the query_range_look_ahead of this ConditionMonitorOutputV1.
        Query range look ahead in seconds

        :param query_range_look_ahead: The query_range_look_ahead of this ConditionMonitorOutputV1.
        :type: int
        """
        if query_range_look_ahead is None:
            raise ValueError("Invalid value for `query_range_look_ahead`, must not be `None`")

        self._query_range_look_ahead = query_range_look_ahead

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ConditionMonitorOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :return: The scoped_to of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ConditionMonitorOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :param scoped_to: The scoped_to of this ConditionMonitorOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def status_message(self):
        """
        Gets the status_message of this ConditionMonitorOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ConditionMonitorOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this ConditionMonitorOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def subscriptions(self):
        """
        Gets the subscriptions of this ConditionMonitorOutputV1.
        The Table Definitions subscribing to the Condition Monitor

        :return: The subscriptions of this ConditionMonitorOutputV1.
        :rtype: list[ItemPreviewV1]
        """
        return self._subscriptions

    @subscriptions.setter
    def subscriptions(self, subscriptions):
        """
        Sets the subscriptions of this ConditionMonitorOutputV1.
        The Table Definitions subscribing to the Condition Monitor

        :param subscriptions: The subscriptions of this ConditionMonitorOutputV1.
        :type: list[ItemPreviewV1]
        """
        if subscriptions is None:
            raise ValueError("Invalid value for `subscriptions`, must not be `None`")

        self._subscriptions = subscriptions

    @property
    def suppressed_conditions(self):
        """
        Gets the suppressed_conditions of this ConditionMonitorOutputV1.
        The suppressed conditions for this condition monitor

        :return: The suppressed_conditions of this ConditionMonitorOutputV1.
        :rtype: list[SuppressedConditionOutputV1]
        """
        return self._suppressed_conditions

    @suppressed_conditions.setter
    def suppressed_conditions(self, suppressed_conditions):
        """
        Sets the suppressed_conditions of this ConditionMonitorOutputV1.
        The suppressed conditions for this condition monitor

        :param suppressed_conditions: The suppressed_conditions of this ConditionMonitorOutputV1.
        :type: list[SuppressedConditionOutputV1]
        """

        self._suppressed_conditions = suppressed_conditions

    @property
    def timezone(self):
        """
        Gets the timezone of this ConditionMonitorOutputV1.
        The IANA timezone in which the schedule will be run, defaults to UTC

        :return: The timezone of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """
        Sets the timezone of this ConditionMonitorOutputV1.
        The IANA timezone in which the schedule will be run, defaults to UTC

        :param timezone: The timezone of this ConditionMonitorOutputV1.
        :type: str
        """

        self._timezone = timezone

    @property
    def translation_key(self):
        """
        Gets the translation_key of this ConditionMonitorOutputV1.
        The item's translation key, if any

        :return: The translation_key of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this ConditionMonitorOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this ConditionMonitorOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this ConditionMonitorOutputV1.
        The type of the item

        :return: The type of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ConditionMonitorOutputV1.
        The type of the item

        :param type: The type of this ConditionMonitorOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def updated_at(self):
        """
        Gets the updated_at of this ConditionMonitorOutputV1.
        The last time the condition monitor was updated

        :return: The updated_at of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """
        Sets the updated_at of this ConditionMonitorOutputV1.
        The last time the condition monitor was updated

        :param updated_at: The updated_at of this ConditionMonitorOutputV1.
        :type: str
        """
        if updated_at is None:
            raise ValueError("Invalid value for `updated_at`, must not be `None`")

        self._updated_at = updated_at

    @property
    def vantages(self):
        """
        Gets the vantages of this ConditionMonitorOutputV1.
        The Vantage Rooms referencing TableDefinitions that subscribe to the Condition Monitor

        :return: The vantages of this ConditionMonitorOutputV1.
        :rtype: list[ItemPreviewV1]
        """
        return self._vantages

    @vantages.setter
    def vantages(self, vantages):
        """
        Sets the vantages of this ConditionMonitorOutputV1.
        The Vantage Rooms referencing TableDefinitions that subscribe to the Condition Monitor

        :param vantages: The vantages of this ConditionMonitorOutputV1.
        :type: list[ItemPreviewV1]
        """
        if vantages is None:
            raise ValueError("Invalid value for `vantages`, must not be `None`")

        self._vantages = vantages

    @property
    def webhook_url(self):
        """
        Gets the webhook_url of this ConditionMonitorOutputV1.
        The URL that is invoked whenever new capsules are found or existing capsules end in any of the conditions.

        :return: The webhook_url of this ConditionMonitorOutputV1.
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """
        Sets the webhook_url of this ConditionMonitorOutputV1.
        The URL that is invoked whenever new capsules are found or existing capsules end in any of the conditions.

        :param webhook_url: The webhook_url of this ConditionMonitorOutputV1.
        :type: str
        """

        self._webhook_url = webhook_url

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConditionMonitorOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionPreviewOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_definitions: List[ColumnDefinitionOutputV1]
    _compute_results: Dict[str, List[RowRulesResultV1]]
    _table: MaterializedTableV1


    def __init__(
        self,
        column_definitions: Optional[List[ColumnDefinitionOutputV1]] = None,
        compute_results: Optional[Dict[str, List[RowRulesResultV1]]] = None,
        table: Optional[MaterializedTableV1] = None,
    ) -> None: ...

    @property
    def column_definitions(self) -> List[ColumnDefinitionOutputV1]: ...

    @column_definitions.setter
    def column_definitions(self, column_definitions: List[ColumnDefinitionOutputV1]) -> None: ...

    @property
    def compute_results(self) -> Dict[str, List[RowRulesResultV1]]: ...

    @compute_results.setter
    def compute_results(self, compute_results: Dict[str, List[RowRulesResultV1]]) -> None: ...

    @property
    def table(self) -> MaterializedTableV1: ...

    @table.setter
    def table(self, table: MaterializedTableV1) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TreemapOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _errors: Optional[List[FormulaCompilerErrorOutputV1]]
    _metadata: Optional[Dict[str, str]]
    _parent_asset: Optional[AssetOutputV1]
    _return_type: Optional[str]
    _status_message: Optional[str]
    _tree: Optional[List[TreemapItemOutputV1]]
    _upgrade_details: Optional[FormulaUpgradeOutputV1]
    _warning_count: Optional[int]
    _warning_logs: Optional[List[FormulaLogV1]]


    def __init__(
        self,
        errors: Optional[List[FormulaCompilerErrorOutputV1]] = None,
        metadata: Optional[Dict[str, str]] = None,
        parent_asset: Optional[AssetOutputV1] = None,
        return_type: Optional[str] = None,
        status_message: Optional[str] = None,
        tree: Optional[List[TreemapItemOutputV1]] = None,
        upgrade_details: Optional[FormulaUpgradeOutputV1] = None,
        warning_count: Optional[int] = None,
        warning_logs: Optional[List[FormulaLogV1]] = None,
    ) -> None: ...

    @property
    def errors(self) -> Optional[List[FormulaCompilerErrorOutputV1]]: ...

    @errors.setter
    def errors(self, errors: Optional[List[FormulaCompilerErrorOutputV1]]) -> None: ...

    @property
    def metadata(self) -> Optional[Dict[str, str]]: ...

    @metadata.setter
    def metadata(self, metadata: Optional[Dict[str, str]]) -> None: ...

    @property
    def parent_asset(self) -> Optional[AssetOutputV1]: ...

    @parent_asset.setter
    def parent_asset(self, parent_asset: Optional[AssetOutputV1]) -> None: ...

    @property
    def return_type(self) -> Optional[str]: ...

    @return_type.setter
    def return_type(self, return_type: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def tree(self) -> Optional[List[TreemapItemOutputV1]]: ...

    @tree.setter
    def tree(self, tree: Optional[List[TreemapItemOutputV1]]) -> None: ...

    @property
    def upgrade_details(self) -> Optional[FormulaUpgradeOutputV1]: ...

    @upgrade_details.setter
    def upgrade_details(self, upgrade_details: Optional[FormulaUpgradeOutputV1]) -> None: ...

    @property
    def warning_count(self) -> Optional[int]: ...

    @warning_count.setter
    def warning_count(self, warning_count: Optional[int]) -> None: ...

    @property
    def warning_logs(self) -> Optional[List[FormulaLogV1]]: ...

    @warning_logs.setter
    def warning_logs(self, warning_logs: Optional[List[FormulaLogV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MaterializedTableSourceV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_column_properties: Optional[List[PropertiesForItemUUIDColumnInputV1]]
    _condition_and_metric_column: str
    _condition_stats: Optional[List[ConditionTableStatInputForTableV1]]
    _table_id: str


    def __init__(
        self,
        additional_column_properties: Optional[List[PropertiesForItemUUIDColumnInputV1]] = None,
        condition_and_metric_column: Optional[str] = None,
        condition_stats: Optional[List[ConditionTableStatInputForTableV1]] = None,
        table_id: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_column_properties(self) -> Optional[List[PropertiesForItemUUIDColumnInputV1]]: ...

    @additional_column_properties.setter
    def additional_column_properties(self, additional_column_properties: Optional[List[PropertiesForItemUUIDColumnInputV1]]) -> None: ...

    @property
    def condition_and_metric_column(self) -> str: ...

    @condition_and_metric_column.setter
    def condition_and_metric_column(self, condition_and_metric_column: str) -> None: ...

    @property
    def condition_stats(self) -> Optional[List[ConditionTableStatInputForTableV1]]: ...

    @condition_stats.setter
    def condition_stats(self, condition_stats: Optional[List[ConditionTableStatInputForTableV1]]) -> None: ...

    @property
    def table_id(self) -> str: ...

    @table_id.setter
    def table_id(self, table_id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelVersionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'creator_name': 'str',
        'notes': 'str',
        'production': 'bool',
        'version': 'int',
        'version_id': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'creator_name': 'creatorName',
        'notes': 'notes',
        'production': 'production',
        'version': 'version',
        'version_id': 'versionId'
    }

    def __init__(self, created_at=None, creator_name=None, notes=None, production=None, version=None, version_id=None):
        """
        ModelVersionOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._creator_name = None
        self._notes = None
        self._production = None
        self._version = None
        self._version_id = None

        if created_at is not None:
          self.created_at = created_at
        if creator_name is not None:
          self.creator_name = creator_name
        if notes is not None:
          self.notes = notes
        if production is not None:
          self.production = production
        if version is not None:
          self.version = version
        if version_id is not None:
          self.version_id = version_id

    @property
    def created_at(self):
        """
        Gets the created_at of this ModelVersionOutputV1.
        ISO-8601 timestamp indicating when this version was published

        :return: The created_at of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ModelVersionOutputV1.
        ISO-8601 timestamp indicating when this version was published

        :param created_at: The created_at of this ModelVersionOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def creator_name(self):
        """
        Gets the creator_name of this ModelVersionOutputV1.
        Display name of the user who published this version

        :return: The creator_name of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._creator_name

    @creator_name.setter
    def creator_name(self, creator_name):
        """
        Sets the creator_name of this ModelVersionOutputV1.
        Display name of the user who published this version

        :param creator_name: The creator_name of this ModelVersionOutputV1.
        :type: str
        """

        self._creator_name = creator_name

    @property
    def notes(self):
        """
        Gets the notes of this ModelVersionOutputV1.
        Notes about this version entered at publish time

        :return: The notes of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this ModelVersionOutputV1.
        Notes about this version entered at publish time

        :param notes: The notes of this ModelVersionOutputV1.
        :type: str
        """

        self._notes = notes

    @property
    def production(self):
        """
        Gets the production of this ModelVersionOutputV1.
        Whether this version is the current production version

        :return: The production of this ModelVersionOutputV1.
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """
        Sets the production of this ModelVersionOutputV1.
        Whether this version is the current production version

        :param production: The production of this ModelVersionOutputV1.
        :type: bool
        """
        if production is None:
            raise ValueError("Invalid value for `production`, must not be `None`")

        self._production = production

    @property
    def version(self):
        """
        Gets the version of this ModelVersionOutputV1.
        The version number (1, 2, 3, etc.)

        :return: The version of this ModelVersionOutputV1.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ModelVersionOutputV1.
        The version number (1, 2, 3, etc.)

        :param version: The version of this ModelVersionOutputV1.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version

    @property
    def version_id(self):
        """
        Gets the version_id of this ModelVersionOutputV1.
        The GUID of the locked Model snapshot for this version

        :return: The version_id of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this ModelVersionOutputV1.
        The GUID of the locked Model snapshot for this version

        :param version_id: The version_id of this ModelVersionOutputV1.
        :type: str
        """
        if version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")

        self._version_id = version_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelVersionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class DatasourceOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'additional_properties': 'list[ScalarPropertyV1]',
        'cache_enabled': 'bool',
        'condition_location': 'str',
        'datasource_class': 'str',
        'datasource_id': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'id': 'str',
        'indexing_schedule_supported': 'bool',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'max_requests': 'int',
        'name': 'str',
        'scim_enabled': 'bool',
        'scoped_to': 'str',
        'seeq_internal': 'bool',
        'signal_location': 'str',
        'status_message': 'str',
        'stored_in_seeq': 'bool',
        'translation_key': 'str',
        'type': 'str'
    }

    attribute_map = {
        'additional_properties': 'additionalProperties',
        'cache_enabled': 'cacheEnabled',
        'condition_location': 'conditionLocation',
        'datasource_class': 'datasourceClass',
        'datasource_id': 'datasourceId',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'id': 'id',
        'indexing_schedule_supported': 'indexingScheduleSupported',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'max_requests': 'maxRequests',
        'name': 'name',
        'scim_enabled': 'scimEnabled',
        'scoped_to': 'scopedTo',
        'seeq_internal': 'seeqInternal',
        'signal_location': 'signalLocation',
        'status_message': 'statusMessage',
        'stored_in_seeq': 'storedInSeeq',
        'translation_key': 'translationKey',
        'type': 'type'
    }

    def __init__(self, additional_properties=None, cache_enabled=False, condition_location=None, datasource_class=None, datasource_id=None, description=None, effective_permissions=None, id=None, indexing_schedule_supported=False, is_archived=False, is_redacted=False, max_requests=None, name=None, scim_enabled=None, scoped_to=None, seeq_internal=False, signal_location=None, status_message=None, stored_in_seeq=False, translation_key=None, type=None):
        """
        DatasourceOutputV1 - a model defined in Swagger
        """

        self._additional_properties = None
        self._cache_enabled = None
        self._condition_location = None
        self._datasource_class = None
        self._datasource_id = None
        self._description = None
        self._effective_permissions = None
        self._id = None
        self._indexing_schedule_supported = None
        self._is_archived = None
        self._is_redacted = None
        self._max_requests = None
        self._name = None
        self._scim_enabled = None
        self._scoped_to = None
        self._seeq_internal = None
        self._signal_location = None
        self._status_message = None
        self._stored_in_seeq = None
        self._translation_key = None
        self._type = None

        if additional_properties is not None:
          self.additional_properties = additional_properties
        if cache_enabled is not None:
          self.cache_enabled = cache_enabled
        if condition_location is not None:
          self.condition_location = condition_location
        if datasource_class is not None:
          self.datasource_class = datasource_class
        if datasource_id is not None:
          self.datasource_id = datasource_id
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if id is not None:
          self.id = id
        if indexing_schedule_supported is not None:
          self.indexing_schedule_supported = indexing_schedule_supported
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if max_requests is not None:
          self.max_requests = max_requests
        if name is not None:
          self.name = name
        if scim_enabled is not None:
          self.scim_enabled = scim_enabled
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if seeq_internal is not None:
          self.seeq_internal = seeq_internal
        if signal_location is not None:
          self.signal_location = signal_location
        if status_message is not None:
          self.status_message = status_message
        if stored_in_seeq is not None:
          self.stored_in_seeq = stored_in_seeq
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DatasourceOutputV1.
        Additional properties of the datasource

        :return: The additional_properties of this DatasourceOutputV1.
        :rtype: list[ScalarPropertyV1]
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DatasourceOutputV1.
        Additional properties of the datasource

        :param additional_properties: The additional_properties of this DatasourceOutputV1.
        :type: list[ScalarPropertyV1]
        """

        self._additional_properties = additional_properties

    @property
    def cache_enabled(self):
        """
        Gets the cache_enabled of this DatasourceOutputV1.
        Whether this datasource's signal data will be cached in Seeq.

        :return: The cache_enabled of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._cache_enabled

    @cache_enabled.setter
    def cache_enabled(self, cache_enabled):
        """
        Sets the cache_enabled of this DatasourceOutputV1.
        Whether this datasource's signal data will be cached in Seeq.

        :param cache_enabled: The cache_enabled of this DatasourceOutputV1.
        :type: bool
        """

        self._cache_enabled = cache_enabled

    @property
    def condition_location(self):
        """
        Gets the condition_location of this DatasourceOutputV1.
        Where this datasource's condition data is stored, if this datasource is stored in seeq

        :return: The condition_location of this DatasourceOutputV1.
        :rtype: str
        """
        return self._condition_location

    @condition_location.setter
    def condition_location(self, condition_location):
        """
        Sets the condition_location of this DatasourceOutputV1.
        Where this datasource's condition data is stored, if this datasource is stored in seeq

        :param condition_location: The condition_location of this DatasourceOutputV1.
        :type: str
        """

        self._condition_location = condition_location

    @property
    def datasource_class(self):
        """
        Gets the datasource_class of this DatasourceOutputV1.
        The class of the datasource

        :return: The datasource_class of this DatasourceOutputV1.
        :rtype: str
        """
        return self._datasource_class

    @datasource_class.setter
    def datasource_class(self, datasource_class):
        """
        Sets the datasource_class of this DatasourceOutputV1.
        The class of the datasource

        :param datasource_class: The datasource_class of this DatasourceOutputV1.
        :type: str
        """

        self._datasource_class = datasource_class

    @property
    def datasource_id(self):
        """
        Gets the datasource_id of this DatasourceOutputV1.
        The ID of the datasource

        :return: The datasource_id of this DatasourceOutputV1.
        :rtype: str
        """
        return self._datasource_id

    @datasource_id.setter
    def datasource_id(self, datasource_id):
        """
        Sets the datasource_id of this DatasourceOutputV1.
        The ID of the datasource

        :param datasource_id: The datasource_id of this DatasourceOutputV1.
        :type: str
        """

        self._datasource_id = datasource_id

    @property
    def description(self):
        """
        Gets the description of this DatasourceOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this DatasourceOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DatasourceOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this DatasourceOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this DatasourceOutputV1.

        :return: The effective_permissions of this DatasourceOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this DatasourceOutputV1.

        :param effective_permissions: The effective_permissions of this DatasourceOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def id(self):
        """
        Gets the id of this DatasourceOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this DatasourceOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DatasourceOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this DatasourceOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def indexing_schedule_supported(self):
        """
        Gets the indexing_schedule_supported of this DatasourceOutputV1.
        Whether for this datasource indexing can be scheduled or requested from Datasource Management UI.

        :return: The indexing_schedule_supported of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._indexing_schedule_supported

    @indexing_schedule_supported.setter
    def indexing_schedule_supported(self, indexing_schedule_supported):
        """
        Sets the indexing_schedule_supported of this DatasourceOutputV1.
        Whether for this datasource indexing can be scheduled or requested from Datasource Management UI.

        :param indexing_schedule_supported: The indexing_schedule_supported of this DatasourceOutputV1.
        :type: bool
        """

        self._indexing_schedule_supported = indexing_schedule_supported

    @property
    def is_archived(self):
        """
        Gets the is_archived of this DatasourceOutputV1.
        Whether item is archived

        :return: The is_archived of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this DatasourceOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this DatasourceOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this DatasourceOutputV1.
        Whether item is redacted

        :return: The is_redacted of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this DatasourceOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this DatasourceOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def max_requests(self):
        """
        Gets the max_requests of this DatasourceOutputV1.
        Configured max requests for the datasource

        :return: The max_requests of this DatasourceOutputV1.
        :rtype: int
        """
        return self._max_requests

    @max_requests.setter
    def max_requests(self, max_requests):
        """
        Sets the max_requests of this DatasourceOutputV1.
        Configured max requests for the datasource

        :param max_requests: The max_requests of this DatasourceOutputV1.
        :type: int
        """

        self._max_requests = max_requests

    @property
    def name(self):
        """
        Gets the name of this DatasourceOutputV1.
        The human readable name

        :return: The name of this DatasourceOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DatasourceOutputV1.
        The human readable name

        :param name: The name of this DatasourceOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scim_enabled(self):
        """
        Gets the scim_enabled of this DatasourceOutputV1.
        Whether SCIM is enabled for this datasource

        :return: The scim_enabled of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._scim_enabled

    @scim_enabled.setter
    def scim_enabled(self, scim_enabled):
        """
        Sets the scim_enabled of this DatasourceOutputV1.
        Whether SCIM is enabled for this datasource

        :param scim_enabled: The scim_enabled of this DatasourceOutputV1.
        :type: bool
        """

        self._scim_enabled = scim_enabled

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this DatasourceOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :return: The scoped_to of this DatasourceOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this DatasourceOutputV1.
        The ID of the workbook to which this item is scoped or null if it is in the global scope.

        :param scoped_to: The scoped_to of this DatasourceOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def seeq_internal(self):
        """
        Gets the seeq_internal of this DatasourceOutputV1.
        Whether this datasource is internal to Seeq (Local Datasource) or not.

        :return: The seeq_internal of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._seeq_internal

    @seeq_internal.setter
    def seeq_internal(self, seeq_internal):
        """
        Sets the seeq_internal of this DatasourceOutputV1.
        Whether this datasource is internal to Seeq (Local Datasource) or not.

        :param seeq_internal: The seeq_internal of this DatasourceOutputV1.
        :type: bool
        """

        self._seeq_internal = seeq_internal

    @property
    def signal_location(self):
        """
        Gets the signal_location of this DatasourceOutputV1.
        Where this datasource's signal data is stored, if this datasource is stored in seeq

        :return: The signal_location of this DatasourceOutputV1.
        :rtype: str
        """
        return self._signal_location

    @signal_location.setter
    def signal_location(self, signal_location):
        """
        Sets the signal_location of this DatasourceOutputV1.
        Where this datasource's signal data is stored, if this datasource is stored in seeq

        :param signal_location: The signal_location of this DatasourceOutputV1.
        :type: str
        """

        self._signal_location = signal_location

    @property
    def status_message(self):
        """
        Gets the status_message of this DatasourceOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this DatasourceOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this DatasourceOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this DatasourceOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def stored_in_seeq(self):
        """
        Gets the stored_in_seeq of this DatasourceOutputV1.
        Whether this datasource's data is stored in Seeq.

        :return: The stored_in_seeq of this DatasourceOutputV1.
        :rtype: bool
        """
        return self._stored_in_seeq

    @stored_in_seeq.setter
    def stored_in_seeq(self, stored_in_seeq):
        """
        Sets the stored_in_seeq of this DatasourceOutputV1.
        Whether this datasource's data is stored in Seeq.

        :param stored_in_seeq: The stored_in_seeq of this DatasourceOutputV1.
        :type: bool
        """

        self._stored_in_seeq = stored_in_seeq

    @property
    def translation_key(self):
        """
        Gets the translation_key of this DatasourceOutputV1.
        The item's translation key, if any

        :return: The translation_key of this DatasourceOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this DatasourceOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this DatasourceOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this DatasourceOutputV1.
        The type of the item

        :return: The type of this DatasourceOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DatasourceOutputV1.
        The type of the item

        :param type: The type of this DatasourceOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, DatasourceOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class HierarchyOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _alias_column_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _filter_grouping: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _name: str
    _scoped_to: Optional[str]
    _status_message: Optional[str]
    _table_definition: ItemPreviewV1
    _table_definition_output: TableDefinitionOutputV1
    _translation_key: Optional[str]
    _type: str
    _view_columns: List[ViewColumnOutputV1]


    def __init__(
        self,
        alias_column_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        filter_grouping: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        table_definition: Optional[ItemPreviewV1] = None,
        table_definition_output: Optional[TableDefinitionOutputV1] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        view_columns: Optional[List[ViewColumnOutputV1]] = None,
    ) -> None: ...

    @property
    def alias_column_id(self) -> Optional[str]: ...

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def filter_grouping(self) -> Optional[str]: ...

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def table_definition(self) -> ItemPreviewV1: ...

    @table_definition.setter
    def table_definition(self, table_definition: ItemPreviewV1) -> None: ...

    @property
    def table_definition_output(self) -> TableDefinitionOutputV1: ...

    @table_definition_output.setter
    def table_definition_output(self, table_definition_output: TableDefinitionOutputV1) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def view_columns(self) -> List[ViewColumnOutputV1]: ...

    @view_columns.setter
    def view_columns(self, view_columns: List[ViewColumnOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AuthInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _auth_provider_class: Optional[str]
    _auth_provider_id: Optional[str]
    _code: Optional[str]
    _password: Optional[str]
    _state: Optional[str]
    _username: Optional[str]


    def __init__(
        self,
        auth_provider_class: Optional[str] = None,
        auth_provider_id: Optional[str] = None,
        code: Optional[str] = None,
        password: Optional[str] = None,
        state: Optional[str] = None,
        username: Optional[str] = None,
    ) -> None: ...

    @property
    def auth_provider_class(self) -> Optional[str]: ...

    @auth_provider_class.setter
    def auth_provider_class(self, auth_provider_class: Optional[str]) -> None: ...

    @property
    def auth_provider_id(self) -> Optional[str]: ...

    @auth_provider_id.setter
    def auth_provider_id(self, auth_provider_id: Optional[str]) -> None: ...

    @property
    def code(self) -> Optional[str]: ...

    @code.setter
    def code(self, code: Optional[str]) -> None: ...

    @property
    def password(self) -> Optional[str]: ...

    @password.setter
    def password(self, password: Optional[str]) -> None: ...

    @property
    def state(self) -> Optional[str]: ...

    @state.setter
    def state(self, state: Optional[str]) -> None: ...

    @property
    def username(self) -> Optional[str]: ...

    @username.setter
    def username(self, username: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...



# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SecretStatus(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _has_value: Optional[bool]


    def __init__(
        self,
        has_value: Optional[bool] = None,
    ) -> None: ...

    @property
    def has_value(self) -> Optional[bool]: ...

    @has_value.setter
    def has_value(self, has_value: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
